period

# XMLRésuméLibrary: User Guide

para | Element Reference | phone

## Name

period — A period of time

## Synopsis

### Content Model

    (from,to)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `period` element defines a specific period in time by specifying the period's start time and end time.

If you want to specify an instant in time instead of a period, use `date`.

### Parents

`period` may be contained in these elements: `award`, `clearance`, `degree`, `job`, `membership`

## See Also

`element`.

## Examples

    <period>
      <from><date>
        <dayOfMonth>10</dayOfMonth>
        <month>February</month>
        <year>1246</year>
      </date></from>
      <to><date>
        <dayOfMonth>19</dayOfMonth>
        <month>November</month>
        <year>1351</year>
      </date></to>
    </period>

    <period>
      <from><date>
        <month>May</month>
        <year>1985</year>
      </date></from>
      <to>
        <present/>
      </to>
    </period>

para | Element Reference | phone